# Backend Sigma

Ce dépôt contient le _backend_ de Sigma, le successeur de Frankiz.

Pour obtenir une copie de ce dépôt, clonez-le avec

    git clone git@gitlab.binets.fr/br/sigma-backend

puis installez les dépendences JavaScript avec

    npm install

## Dépendances

Une dépendance, c'est un librairie JavaScript dont dépend le code source, soit pour le faire tourner soit pour faire tourner les outils dévs. Les dépendances dév servent à tester par exemple. On trouve la liste des dépendances dans `package.json`. Express est un exemple de dépendance normale, nodemon et ESLint (voir infra) sont des dépendances dev (`devDependencies`).

## Structure

Les fichiers source se situent dans le dossier `src`.

Pour l'instant, le serveur utilisé est [express.js](https://expressjs.com/) ; le serveur Express est configuré dans `server.js` puis lancé sur le port 8888 dans `index.js`.

La syntaxe adoptée est JavaScript ES6, un standard moderne (2015) de JavaScript. Il permet d'importer des dépendances en utilisant le mot-clé `import`, ce que le serveur Node.js ne comprend pas puisque la version 8.0 de Node ne comprend que le standard ES5, qui gère les imports avec `require()`.

Le fichier serveur que Node reconnaît est `dist/bundle.js`.

## Scripts

Les scripts sont des instructions en ligne de commande que l'on peut faire tourner avec la commande `npm run`. Ils sont définis dans `package.json`.

### Transpiler le serveur

On utilisera Webpack pour transpiler le fichier source `src/index.js` en `dist/bundle.js` qui est suit la syntaxe ES5 compatible Node. Pour ça, on utilise

* `npm run build` qui exécute la commande `webpack` avec le fichier de configuration `webpack.config.js`, ou
* `npm run watch` qui recompile automatiquement dès que le code est modifié.

### Démarrer le serveur

Pour faire tourner le serveur, il y a deux options :

* `npm start` fait tourner le serveur `bundle.js` en mode prod sur le port 8888 (donc il faut consulter https://localhost:8888)
* `npm test` le démarre avec [nodemon](https://nodemon.io/), outil dév qui redémarre automatiquement le serveur dans `bundle.js` dès que celui-ci est modifié.

Donc, combiner `npm run watch` et `npm test` permet de recompiler le serveur __et__ le redémarrer automatiquement dès qu'il y a une modification.

## ESLint

On utilisera ESLint pour standardiser le code : un ensemble de règles de style pour le code sont appliquées, et quelques-unes d'entre elles sont dans le fichier `.eslintrc.json`. Pour l'instant, la config ESLint impose d'utiliser quatre espaces pour les indentations et de ne pas utiliser de point-virgule en fin de ligne.

Pour faire valider un fichier `file.js` par ESLint, utilisez

    npm run eslint file.js

et avec l'option `--fix` pour corriger le fichier.

Sinon, si vous utilisez Atom ou Visual Studio Code pour éditer votre code, il existe des plugins qui font tourner ESLint en _live_ sur le code et vérifient que tout est en ordre.

Pour mieux comprendre ESLint, référez-vous à la [doc](https://eslint.org/docs/user-guide/getting-started).
